aboutsummaryrefslogtreecommitdiff
path: root/src/backend/executor/nodeSetOp.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/executor/nodeSetOp.c')
-rw-r--r--src/backend/executor/nodeSetOp.c30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/backend/executor/nodeSetOp.c b/src/backend/executor/nodeSetOp.c
index 09089204e8b..54311d31e0e 100644
--- a/src/backend/executor/nodeSetOp.c
+++ b/src/backend/executor/nodeSetOp.c
@@ -92,23 +92,23 @@ build_hash_table(SetOpState *setopstate)
/*
* If both child plans deliver the same fixed tuple slot type, we can tell
* BuildTupleHashTableExt to expect that slot type as input. Otherwise,
* we'll pass NULL denoting that any slot type is possible.
*/
- setopstate->hashtable = BuildTupleHashTableExt(&setopstate->ps,
- desc,
- ExecGetCommonChildSlotOps(&setopstate->ps),
- node->numCols,
- node->cmpColIdx,
- setopstate->eqfuncoids,
- setopstate->hashfunctions,
- node->cmpCollations,
- node->numGroups,
- 0,
- setopstate->ps.state->es_query_cxt,
- setopstate->tableContext,
- econtext->ecxt_per_tuple_memory,
- false);
+ setopstate->hashtable = BuildTupleHashTable(&setopstate->ps,
+ desc,
+ ExecGetCommonChildSlotOps(&setopstate->ps),
+ node->numCols,
+ node->cmpColIdx,
+ setopstate->eqfuncoids,
+ setopstate->hashfunctions,
+ node->cmpCollations,
+ node->numGroups,
+ 0,
+ setopstate->ps.state->es_query_cxt,
+ setopstate->tableContext,
+ econtext->ecxt_per_tuple_memory,
+ false);
}
/*
@@ -92,23 +92,23 @@ build_hash_table(SetOpState *setopstate)
/*
* If both child plans deliver the same fixed tuple slot type, we can tell
- * BuildTupleHashTableExt to expect that slot type as input. Otherwise,
+ * BuildTupleHashTable to expect that slot type as input. Otherwise,
* we'll pass NULL denoting that any slot type is possible.
*/